==> ejc-supbid-impl-3.0.1-20220124.080804-130-sources.jar: com/ejianc/business/supbid/winbid/bean/WinbidEntity.java <==
package com.ejianc.business.supbid.winbid.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;

/**
 * 中标实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_notice_winbid")
public class WinbidEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private java.lang.String sourceId; // 来源id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 中标编号
    @TableField(value="source_project_id")
    private java.lang.String sourceProjectId; // 发布项目ID
    @TableField(value="project_name")
    private java.lang.String projectName; // 发布项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 发布项目编号
    @TableField(value="source_org_id")
    private java.lang.String sourceOrgId; // 发布组织ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 发布组织名称
    @TableField(value="source_unit_id")
    private java.lang.String sourceUnitId; // 招标单位ID
    @TableField(value="unit_name")
    private java.lang.String unitName; // 招标单位名称
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="type")
    private java.lang.String type; // 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
    @TableField(value="tender_name")
    private java.lang.String tenderName; // 招标名称
    @TableField(value="tender_type")
    private java.lang.Integer tenderType; // 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
    @TableField(value="source_employee_id")
    private java.lang.String sourceEmployeeId; // 招标联系人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 招标联系人名称
    @TableField(value="employee_mobile")
    private java.lang.String employeeMobile; // 招标联系人电话
    @TableField(value="purchase_type")
    private java.lang.Integer purchaseType; // 采购方式(0-项目采购,1-单位采购)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="notice_bid_time")
    private java.util.Date noticeBidTime; // 开标时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="notice_winbid_time")
    private java.util.Date noticeWinbidTime; // 中标时间
    @TableField(value="winbid_money")
    private java.math.BigDecimal winbidMoney; // 中标总额
    @TableField(value="winbid_money_tax")
    private java.math.BigDecimal winbidMoneyTax; // 中标总额(含税)
    @TableField(value="winbid_type")
    private java.lang.Integer winbidType; // 0-中标，1-流标，2-废标
    @ApiModelProperty("system_id")
    private String systemId;

    @TableField(exist=false)
    @SubEntity(serviceName="winbidDetailService",pidName = "winbidId")
    private List<WinbidDetailEntity> winbidDetailList = new ArrayList<>(); // 中标明细

    @TableField(exist=false)
    @SubEntity(serviceName="subWinbidDetailService",pidName = "winbidId")
    private List<SubWinbidDetailEntity> subWinbidDetailList = new ArrayList<>(); // 分包中标明细

    @TableField(exist=false)
    @SubEntity(serviceName="purchaseWinbidDetailService",pidName = "winbidId")
    private List<PurchaseWinbidDetailEntity> purchaseWinbidDetailList = new ArrayList<>(); // 分包中标明细


    public List<WinbidDetailEntity> getWinbidDetailList() {
        return winbidDetailList;
    }

    public void setWinbidDetailList(List<WinbidDetailEntity> winbidDetailList) {
        this.winbidDetailList = winbidDetailList;
    }

    public List<SubWinbidDetailEntity> getSubWinbidDetailList() {
        return subWinbidDetailList;
    }

    public void setSubWinbidDetailList(List<SubWinbidDetailEntity> subWinbidDetailList) {
        this.subWinbidDetailList = subWinbidDetailList;
    }

    public Integer getWinbidType() {
        return winbidType;
    }

    public void setWinbidType(Integer winbidType) {
        this.winbidType = winbidType;
    }

    /**
     * 来源id
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 来源id
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 中标编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 中标编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发布项目ID
     */
    public java.lang.String getSourceProjectId() {
        return sourceProjectId;
    }

    /**
     * 发布项目ID
     */
    public void setSourceProjectId(java.lang.String sourceProjectId) {
        this.sourceProjectId = sourceProjectId;
    }
    /**
     * 发布项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 发布项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 发布项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 发布项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 发布组织ID
     */
    public java.lang.String getSourceOrgId() {
        return sourceOrgId;
    }

    /**
     * 发布组织ID
     */
    public void setSourceOrgId(java.lang.String sourceOrgId) {
        this.sourceOrgId = sourceOrgId;
    }
    /**
     * 发布组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 发布组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 招标单位ID
     */
    public java.lang.String getSourceUnitId() {
        return sourceUnitId;
    }

    /**
     * 招标单位ID
     */
    public void setSourceUnitId(java.lang.String sourceUnitId) {
        this.sourceUnitId = sourceUnitId;
    }
    /**
     * 招标单位名称
     */
    public java.lang.String getUnitName() {
        return unitName;
    }

    /**
     * 招标单位名称
     */
    public void setUnitName(java.lang.String unitName) {
        this.unitName = unitName;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }
    /**
     * 招标名称
     */
    public java.lang.String getTenderName() {
        return tenderName;
    }

    /**
     * 招标名称
     */
    public void setTenderName(java.lang.String tenderName) {
        this.tenderName = tenderName;
    }
    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public java.lang.Integer getTenderType() {
        return tenderType;
    }

    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public void setTenderType(java.lang.Integer tenderType) {
        this.tenderType = tenderType;
    }
    /**
     * 招标联系人
     */
    public java.lang.String getSourceEmployeeId() {
        return sourceEmployeeId;
    }

    /**
     * 招标联系人
     */
    public void setSourceEmployeeId(java.lang.String sourceEmployeeId) {
        this.sourceEmployeeId = sourceEmployeeId;
    }
    /**
     * 招标联系人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 招标联系人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 招标联系人电话
     */
    public java.lang.String getEmployeeMobile() {
        return employeeMobile;
    }

    /**
     * 招标联系人电话
     */
    public void setEmployeeMobile(java.lang.String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }
    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public java.lang.Integer getPurchaseType() {
        return purchaseType;
    }

    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public void setPurchaseType(java.lang.Integer purchaseType) {
        this.purchaseType = purchaseType;
    }
    /**
     * 开标时间
     */
    public java.util.Date getNoticeBidTime() {
        return noticeBidTime;
    }

    /**
     * 开标时间
     */
    public void setNoticeBidTime(java.util.Date noticeBidTime) {
        this.noticeBidTime = noticeBidTime;
    }
    /**
     * 中标时间
     */
    public java.util.Date getNoticeWinbidTime() {
        return noticeWinbidTime;
    }

    /**
     * 中标时间
     */
    public void setNoticeWinbidTime(java.util.Date noticeWinbidTime) {
        this.noticeWinbidTime = noticeWinbidTime;
    }
    /**
     * 中标总额
     */
    public java.math.BigDecimal getWinbidMoney() {
        return winbidMoney;
    }

    /**
     * 中标总额
     */
    public void setWinbidMoney(java.math.BigDecimal winbidMoney) {
        this.winbidMoney = winbidMoney;
    }
    /**
     * 中标总额(含税)
     */
    public java.math.BigDecimal getWinbidMoneyTax() {
        return winbidMoneyTax;
    }

    /**
     * 中标总额(含税)
     */
    public void setWinbidMoneyTax(java.math.BigDecimal winbidMoneyTax) {
        this.winbidMoneyTax = winbidMoneyTax;
    }

    public String getSystemId() {
        return systemId;
    }

    public void setSystemId(String systemId) {
        this.systemId = systemId;
    }

    public List<PurchaseWinbidDetailEntity> getPurchaseWinbidDetailList() {
        return purchaseWinbidDetailList;
    }

    public void setPurchaseWinbidDetailList(List<PurchaseWinbidDetailEntity> purchaseWinbidDetailList) {
        this.purchaseWinbidDetailList = purchaseWinbidDetailList;
    }
}

==> ejc-supbid-impl-3.0.1-20231122.012641-251-sources.jar: com/ejianc/business/supbid/winbid/bean/WinbidEntity.java <==
package com.ejianc.business.supbid.winbid.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;

/**
 * 中标实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_notice_winbid")
public class WinbidEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private java.lang.String sourceId; // 来源id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 中标编号
    @TableField(value="source_project_id")
    private java.lang.String sourceProjectId; // 发布项目ID
    @TableField(value="project_name")
    private java.lang.String projectName; // 发布项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 发布项目编号
    @TableField(value="source_org_id")
    private java.lang.String sourceOrgId; // 发布组织ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 发布组织名称
    @TableField(value="source_unit_id")
    private java.lang.String sourceUnitId; // 招标单位ID
    @TableField(value="unit_name")
    private java.lang.String unitName; // 招标单位名称
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="type")
    private java.lang.String type; // 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
    @TableField(value="tender_name")
    private java.lang.String tenderName; // 招标名称
    @TableField(value="tender_type")
    private java.lang.Integer tenderType; // 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
    @TableField(value="source_employee_id")
    private java.lang.String sourceEmployeeId; // 招标联系人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 招标联系人名称
    @TableField(value="employee_mobile")
    private java.lang.String employeeMobile; // 招标联系人电话
    @TableField(value="purchase_type")
    private java.lang.Integer purchaseType; // 采购方式(0-项目采购,1-单位采购)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="notice_bid_time")
    private java.util.Date noticeBidTime; // 开标时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="notice_winbid_time")
    private java.util.Date noticeWinbidTime; // 中标时间
    @TableField(value="winbid_money")
    private java.math.BigDecimal winbidMoney; // 中标总额
    @TableField(value="winbid_money_tax")
    private java.math.BigDecimal winbidMoneyTax; // 中标总额(含税)
    @TableField(value="winbid_type")
    private java.lang.Integer winbidType; // 0-中标，1-流标，2-废标
    @ApiModelProperty("system_id")
    private String systemId;

    @TableField(exist=false)
    @SubEntity(serviceName="winbidDetailService",pidName = "winbidId")
    private List<WinbidDetailEntity> winbidDetailList = new ArrayList<>(); // 中标明细

    @TableField(exist=false)
    @SubEntity(serviceName="subWinbidDetailService",pidName = "winbidId")
    private List<SubWinbidDetailEntity> subWinbidDetailList = new ArrayList<>(); // 分包中标明细

    @TableField(exist=false)
    @SubEntity(serviceName="purchaseWinbidDetailService",pidName = "winbidId")
    private List<PurchaseWinbidDetailEntity> purchaseWinbidDetailList = new ArrayList<>(); // 设备采购中标明细

    @TableField(exist=false)
    @SubEntity(serviceName="rentWinbidDetailService",pidName = "winbidId")
    private List<RentWinbidDetailEntity> rentWinbidDetailList = new ArrayList<>(); // 设备租赁中标明细

    @TableField(exist=false)
    @SubEntity(serviceName="rmatWinbidDetailService",pidName = "winbidId")
    private List<RmatWinbidDetailEntity> rmatWinbidDetailList = new ArrayList<>(); // 周转材租赁中标明细

    @TableField(exist=false)
    @SubEntity(serviceName="otherWinbidDetailService",pidName = "winbidId")
    private List<OtherWinbidDetailEntity> otherWinbidDetailList = new ArrayList<>(); // 其他中标明细



    public List<WinbidDetailEntity> getWinbidDetailList() {
        return winbidDetailList;
    }

    public void setWinbidDetailList(List<WinbidDetailEntity> winbidDetailList) {
        this.winbidDetailList = winbidDetailList;
    }

    public List<SubWinbidDetailEntity> getSubWinbidDetailList() {
        return subWinbidDetailList;
    }

    public void setSubWinbidDetailList(List<SubWinbidDetailEntity> subWinbidDetailList) {
        this.subWinbidDetailList = subWinbidDetailList;
    }

    public Integer getWinbidType() {
        return winbidType;
    }

    public void setWinbidType(Integer winbidType) {
        this.winbidType = winbidType;
    }

    /**
     * 来源id
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 来源id
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 中标编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 中标编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发布项目ID
     */
    public java.lang.String getSourceProjectId() {
        return sourceProjectId;
    }

    /**
     * 发布项目ID
     */
    public void setSourceProjectId(java.lang.String sourceProjectId) {
        this.sourceProjectId = sourceProjectId;
    }
    /**
     * 发布项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 发布项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 发布项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 发布项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 发布组织ID
     */
    public java.lang.String getSourceOrgId() {
        return sourceOrgId;
    }

    /**
     * 发布组织ID
     */
    public void setSourceOrgId(java.lang.String sourceOrgId) {
        this.sourceOrgId = sourceOrgId;
    }
    /**
     * 发布组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 发布组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 招标单位ID
     */
    public java.lang.String getSourceUnitId() {
        return sourceUnitId;
    }

    /**
     * 招标单位ID
     */
    public void setSourceUnitId(java.lang.String sourceUnitId) {
        this.sourceUnitId = sourceUnitId;
    }
    /**
     * 招标单位名称
     */
    public java.lang.String getUnitName() {
        return unitName;
    }

    /**
     * 招标单位名称
     */
    public void setUnitName(java.lang.String unitName) {
        this.unitName = unitName;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }
    /**
     * 招标名称
     */
    public java.lang.String getTenderName() {
        return tenderName;
    }

    /**
     * 招标名称
     */
    public void setTenderName(java.lang.String tenderName) {
        this.tenderName = tenderName;
    }
    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public java.lang.Integer getTenderType() {
        return tenderType;
    }

    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public void setTenderType(java.lang.Integer tenderType) {
        this.tenderType = tenderType;
    }
    /**
     * 招标联系人
     */
    public java.lang.String getSourceEmployeeId() {
        return sourceEmployeeId;
    }

    /**
     * 招标联系人
     */
    public void setSourceEmployeeId(java.lang.String sourceEmployeeId) {
        this.sourceEmployeeId = sourceEmployeeId;
    }
    /**
     * 招标联系人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 招标联系人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 招标联系人电话
     */
    public java.lang.String getEmployeeMobile() {
        return employeeMobile;
    }

    /**
     * 招标联系人电话
     */
    public void setEmployeeMobile(java.lang.String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }
    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public java.lang.Integer getPurchaseType() {
        return purchaseType;
    }

    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public void setPurchaseType(java.lang.Integer purchaseType) {
        this.purchaseType = purchaseType;
    }
    /**
     * 开标时间
     */
    public java.util.Date getNoticeBidTime() {
        return noticeBidTime;
    }

    /**
     * 开标时间
     */
    public void setNoticeBidTime(java.util.Date noticeBidTime) {
        this.noticeBidTime = noticeBidTime;
    }
    /**
     * 中标时间
     */
    public java.util.Date getNoticeWinbidTime() {
        return noticeWinbidTime;
    }

    /**
     * 中标时间
     */
    public void setNoticeWinbidTime(java.util.Date noticeWinbidTime) {
        this.noticeWinbidTime = noticeWinbidTime;
    }
    /**
     * 中标总额
     */
    public java.math.BigDecimal getWinbidMoney() {
        return winbidMoney;
    }

    /**
     * 中标总额
     */
    public void setWinbidMoney(java.math.BigDecimal winbidMoney) {
        this.winbidMoney = winbidMoney;
    }
    /**
     * 中标总额(含税)
     */
    public java.math.BigDecimal getWinbidMoneyTax() {
        return winbidMoneyTax;
    }

    /**
     * 中标总额(含税)
     */
    public void setWinbidMoneyTax(java.math.BigDecimal winbidMoneyTax) {
        this.winbidMoneyTax = winbidMoneyTax;
    }

    public String getSystemId() {
        return systemId;
    }

    public void setSystemId(String systemId) {
        this.systemId = systemId;
    }

    public List<PurchaseWinbidDetailEntity> getPurchaseWinbidDetailList() {
        return purchaseWinbidDetailList;
    }

    public void setPurchaseWinbidDetailList(List<PurchaseWinbidDetailEntity> purchaseWinbidDetailList) {
        this.purchaseWinbidDetailList = purchaseWinbidDetailList;
    }

    public List<RentWinbidDetailEntity> getRentWinbidDetailList() {
        return rentWinbidDetailList;
    }

    public void setRentWinbidDetailList(List<RentWinbidDetailEntity> rentWinbidDetailList) {
        this.rentWinbidDetailList = rentWinbidDetailList;
    }

    public List<RmatWinbidDetailEntity> getRmatWinbidDetailList() {
        return rmatWinbidDetailList;
    }

    public void setRmatWinbidDetailList(List<RmatWinbidDetailEntity> rmatWinbidDetailList) {
        this.rmatWinbidDetailList = rmatWinbidDetailList;
    }

    public List<OtherWinbidDetailEntity> getOtherWinbidDetailList() {
        return otherWinbidDetailList;
    }

    public void setOtherWinbidDetailList(List<OtherWinbidDetailEntity> otherWinbidDetailList) {
        this.otherWinbidDetailList = otherWinbidDetailList;
    }
}
